@@ -6,7 +6,7 @@ import pandas as pd
 import numpy as np
 import argparse
 p_dir = os.path.dirname(os.path.realpath(__file__)) + "/"
-code_dir = p_dir+"../scripts/"
+code_dir = p_dir+"scripts/"
 def run_matlab_code(seq):
 	
 	# step 1: copy matlab code to users folder because matlab scripts can't take parameters
